aboutsummaryrefslogtreecommitdiffstats
path: root/src/nativewindow/classes/javax/media
diff options
context:
space:
mode:
Diffstat (limited to 'src/nativewindow/classes/javax/media')
-rw-r--r--src/nativewindow/classes/javax/media/nativewindow/OffscreenLayerSurface.java10
1 files changed, 4 insertions, 6 deletions
diff --git a/src/nativewindow/classes/javax/media/nativewindow/OffscreenLayerSurface.java b/src/nativewindow/classes/javax/media/nativewindow/OffscreenLayerSurface.java
index 81983a7c2..cf8cf89d2 100644
--- a/src/nativewindow/classes/javax/media/nativewindow/OffscreenLayerSurface.java
+++ b/src/nativewindow/classes/javax/media/nativewindow/OffscreenLayerSurface.java
@@ -27,11 +27,9 @@
*/
package javax.media.nativewindow;
-import java.io.IOException;
-
+import javax.media.nativewindow.util.PixelRectangle;
import javax.media.nativewindow.util.PointImmutable;
-import com.jogamp.common.util.IOUtil;
import com.jogamp.common.util.locks.RecursiveLock;
/**
@@ -73,12 +71,12 @@ public interface OffscreenLayerSurface {
/**
* Optional method setting cursor in the corresponding on-screen surface/window, if exists.
*
* @param resources maybe null for default cursor
* @param hotSpot maybe null for default cursor
* @return true if successful, i.e. on-screen surface/window w/ cursor capabilities exists. Otherwise false.
- * @throws IOException
*/
- public boolean setCursor(IOUtil.ClassResources resources, PointImmutable hotSpot) throws IOException;
+ public boolean setCursor(PixelRectangle pixelrect, PointImmutable hotSpot);
+
/**
* Optional method hiding the cursor in the corresponding on-screen surface/window, if exists.
*
@@ -73,12 +71,12 @@ public interface OffscreenLayerSurface {
* Optional method setting cursor in the corresponding on-screen surface/window, if exists.
*
- * @param resources maybe null for default cursor
+ * @param pixelrect cursor pixels, maybe null for default cursor
* @param hotSpot maybe null for default cursor
* @return true if successful, i.e. on-screen surface/window w/ cursor capabilities exists. Otherwise false.